@@ -1,11 +1,19 @@
 #input subject, time, test and ref concentration
+###
+### NCAdata(), NCAcsv() -> for ;NCA only' data input;
+### BANOVAdata(), BANOVAcsv() -> for 'statistical analysis only' data input;
+### NCA.BANOVAdata(), NCA.BANOVAcsv() for 'NCA -> statistical analysis' data input.
+###
 NCAdata<-function(replicated=FALSE, parallel=FALSE, multiple=FALSE)
 {
 cat("\n")
+
+Fname<-Fname
+
 file.menu <- c("Input/edit data from keyboard",
                "Import data file with .csv format",
                "Load data File with .RData format",
-               "Back to NCA menu",
+               "Back to top menu",
                "Quit")
 cat("\n")
 
@@ -70,30 +78,36 @@ if (pick == 1){
         else{
               saveRDS(TotalSingledata,TotalSinglename)
           }
-           if(parallel){
+          
+          Fname<<-TotalSinglename
+          
+       ###
+       ### now starting checking if the dataset is incomplete data (icd); if it is then stop running;
+       ### if it is not, then go to analysis (see icd.check()). 'TotalSingledata' is the first dataset
+       ### generated by bear once the raw data has been loaded; same as for NCAcsv().
+       ###
+       if(parallel){
              if(multiple){
-              return(MultipleParaNCAanalyze(TotalSingledata))
+                 icd.check(TotalSingledata,parallel=TRUE,multiple=TRUE,replicated=FALSE,NCA.only=TRUE)
                }
               else{
-               return(ParaNCAanalyze(TotalSingledata))
+                 icd.check(TotalSingledata,parallel=TRUE,multiple=FALSE,replicated=FALSE,NCA.only=TRUE)
                }
            }
-           else{ 
+       else{ 
             if (replicated){
-              return(RepNCAanalyze(TotalSingledata))
+                 icd.check(TotalSingledata,parallel=FALSE,multiple=FALSE,replicated=TRUE,NCA.only=TRUE)
              }
            else{
               if(multiple){
-                 return(MultipleNCAanalyze(TotalSingledata))
+                 icd.check(TotalSingledata,parallel=FALSE,multiple=TRUE,replicated=FALSE,NCA.only=TRUE)
                   }
                else{ 
-                 return(NCAanalyze(TotalSingledata))
-                 } 
-             }  
-         }
+                 icd.check(TotalSingledata,parallel=FALSE,multiple=FALSE,replicated=FALSE,NCA.only=TRUE)
+               } 
+          }  
+      }
       }    
-    
-
 else {
   if (pick == 2){
        cat("\n")                                          
@@ -129,7 +143,8 @@ else {
 ##     TotalSinglename <-readline() 
 ##     TotalSinglename<-paste(TotalSinglename,".RData",sep="")
 ##     load(TotalSinglename)
-     TotalSingledata<-readRDS(file.choose())  # musch better than using load()
+     TotalSingledata<-readRDS(xx<-file.choose())  # musch better than using load()
+     Fname<<- basename(xx)      ### this will not work with 'Fname<<- basename(TotalSingledata)'   
      TotalSingledata<-edit(TotalSingledata)
      ### TotalSingledata<-na.omit(TotalSingledata)   ### v2.6.1
          if(parallel){
@@ -150,59 +165,41 @@ else {
          ### saveRDS(TotalSingledata,TotalSinglename)
          ### write.csv(TotalSingledata,TotalSinglename,row.names=FALSE)                     ### is it necessary? -YJ
          cat("\n\n")
-         if(parallel){
-           if(multiple){
-              return(MultipleParaNCAanalyze(TotalSingledata))
+         
+       if(parallel){
+             if(multiple){
+                 icd.check(TotalSingledata,parallel=TRUE,multiple=TRUE,replicated=FALSE,NCA.only=TRUE)
                }
               else{
-               return(ParaNCAanalyze(TotalSingledata))
+                 icd.check(TotalSingledata,parallel=TRUE,multiple=FALSE,replicated=FALSE,NCA.only=TRUE)
                }
-         }
-          else{ 
-           if (replicated){
-             return(RepNCAanalyze(TotalSingledata))
+           }
+       else{ 
+            if (replicated){
+                 icd.check(TotalSingledata,parallel=FALSE,multiple=FALSE,replicated=TRUE,NCA.only=TRUE)
              }
-            else{
-                if(multiple){
-                return(MultipleNCAanalyze(TotalSingledata))
-                }
-                else{ 
-                return(NCAanalyze(TotalSingledata))
+           else{
+              if(multiple){
+                 icd.check(TotalSingledata,parallel=FALSE,multiple=TRUE,replicated=FALSE,NCA.only=TRUE)
+                  }
+               else{ 
+                 icd.check(TotalSingledata,parallel=FALSE,multiple=FALSE,replicated=FALSE,NCA.only=TRUE)
                } 
-             }
-          } 
+          }  
+      }        
       }
 
   else {
   if (pick == 4){
-     cat("\n\n")
-         if(parallel){
-            if(multiple){
-            MultipleParamenu() 
-              }
-             else{ 
-            Paramenu()
-            } 
-          }
-         else{
-           if (replicated){
-              Repmenu()
-             }
-           else{
-               if(multiple){
-               MultipleNCAmenu()
-               }
-               else{ 
-               NCAmenu()
-             }
-          }
-      }
+     graphics.off();cat("\n\n")
+     go2menu()
 }
   else {
+  
   if (pick == 5){
      cat("\n  Thank you for using bear!  Bye now. \n\n")
      graphics.off()
-                }
+        }
      }
     }
    }
