@@ -3,5 +3,6 @@ RepNCA.MIX<-function(Totalplot,Dose, ref_data, test_data, SingleRdata, SingleRda
 SingleTdata,SingleTdata1,xaxis, yaxis,rdata.split,tdata.split){
 
 NCA(Totalplot,Dose, ref_data, test_data, SingleRdata, SingleRdata1,SingleTdata,
-    SingleTdata1,xaxis, yaxis,rdata.split,tdata.split,Demo=FALSE, BANOVA=FALSE,replicated=TRUE,MIX=TRUE, parallel=FALSE)
+    SingleTdata1,xaxis, yaxis,rdata.split,tdata.split,Demo=FALSE, BANOVA=FALSE,
+    replicated=TRUE,MIX=TRUE, parallel=FALSE)
 }
\ No newline at end of file
