@@ -1,5 +1,6 @@
+#select 3 points (NCA -> lme) for replicated study
 RepNCAselect.MIX<-function(Totalplot,SingleRdata1,SingleTdata1, Dose,SingleRdata,SingleTdata,xaxis, yaxis){
 
 NCAselect(Totalplot,SingleRdata1,SingleTdata1, Dose,SingleRdata,SingleTdata,xaxis, yaxis,
-          Demo=FALSE, BANOVA=FALSE, replicated=TRUE,MIX=TRUE)
+          Demo=FALSE, BANOVA=FALSE, replicated=TRUE,MIX=TRUE, parallel=FALSE)
 }
\ No newline at end of file
