@@ -1,4 +1,4 @@
 RepTTTARSoutput<-function(sumindexR, sumindexT,R.split,T.split,keindex_ref,keindex_test,Dose,TotalData){
 NCAoutput(sumindexR, sumindexT,R.split,T.split,keindex_ref,keindex_test,Dose,TotalData,
-          NCA=FALSE,ARS=FALSE,TTT=FALSE,aic=FALSE,TTTARS=TRUE,TTTAIC=FALSE, replicated=TRUE)
+          NCA=FALSE,ARS=FALSE,TTT=FALSE,aic=FALSE,TTTARS=TRUE,TTTAIC=FALSE, replicated=TRUE, parallel=FALSE)
 }
\ No newline at end of file
