@@ -1052,7 +1052,8 @@ RepTTToutput(sumindexR, sumindexT,R.split,T.split,keindex_ref,keindex_test,Dose,
 RepNCAplot(Totalplot,SingleRdata,SingleTdata,TotalData,xaxis,yaxis)
  if (Demo){
          #Demo=TRUE, MIX=FALSE
-         Repmenu()
+         ### Repmenu()
+         cat("\n\n");go2menu()
         }
        else {
          if(MIX){
@@ -1074,7 +1075,8 @@ else{
         MultipleParaNCAplot(Totalplot,SingleRdata,SingleTdata,TotalData,xaxis,yaxis,TlastD)
           if (Demo){
           #Demo=TRUE, BANOVA=FALSE
-          MultipleParamenu()
+          ### MultipleParamenu()
+          cat("\n\n");go2menu()
           }
            else {
              if(MIX){
@@ -1092,7 +1094,8 @@ else{
       ParaNCAplot(Totalplot,SingleRdata,SingleTdata,TotalData,xaxis,yaxis) 
       if (Demo){
          #Demo=TRUE, MIX=FALSE
-         Paramenu()
+         ### Paramenu()
+         cat("\n\n");go2menu()
         }
        else {
          if(MIX){
@@ -1114,11 +1117,12 @@ else{
         MultipleNCAplot(Totalplot,SingleRdata,SingleTdata,TotalData,xaxis,yaxis,TlastD)
           if (Demo){
           #Demo=TRUE, BANOVA=FALSE
-          MultipleNCAmenu()
+          ### MultipleNCAmenu()
+          cat("\n\n");go2menu()
           }
            else {
              if(BANOVA){
-            ##Demo=FALSE, BANOVA=TRUE
+             ##Demo=FALSE, BANOVA=TRUE
              MultipleBANOVAanalyze(TotalData)
                 }
              else{
@@ -1132,12 +1136,13 @@ else{
      NCAplot(Totalplot,SingleRdata,SingleTdata,TotalData,xaxis,yaxis)
 
       if (Demo){
-      #Demo=TRUE, BANOVA=FALSE
-      NCAmenu()
+        #Demo=TRUE, BANOVA=FALSE
+        ### NCAmenu()
+        cat("\n\n");go2menu()
         }
       else {
        if(BANOVA){
-       ##Demo=FALSE, BANOVA=TRUE
+        ##Demo=FALSE, BANOVA=TRUE
         BANOVAanalyze(TotalData)
         }
         else{
