@@ -1,7 +1,7 @@
 description_import<-function(){
-   cat("\n\n")
+   cat("\n")
    filepath<-getwd()
    cat(" bear will read and import your data file (*.csv) from\n")
-   cat("",filepath,"by default.\n\n")
+   cat("",filepath,"by default.\n")
    readline(" Press Enter to select file...")
 }
\ No newline at end of file
